@@ -9,6 +9,26 @@
 #include "threads.h"
 
 
+/*
+ * Values for CitContext.state
+ * 
+ * A session that is doing nothing is in CON_IDLE state.  When activity
+ * is detected on the socket, it goes to CON_READY, indicating that it
+ * needs to have a worker thread bound to it.  When a thread binds to
+ * the session, it goes to CON_EXECUTING and does its thing.  When the
+ * transaction is finished, the thread sets it back to CON_IDLE and lets
+ * it go.
+ */
+typedef enum __CCState {
+	CON_IDLE,		/* This context is doing nothing */
+	CON_GREETING,		/* This context needs to output its greeting */
+	CON_STARTING,		/* This context is outputting its greeting */
+	CON_READY,		/* This context needs attention */
+	CON_EXECUTING,		/* This context is bound to a thread */
+	CON_SYS                 /* This is a system context and mustn't be purged */
+} CCState;
+
+
 /*
  * Here's the big one... the Citadel context structure.
  *
@@ -22,21 +42,24 @@ struct CitContext {
 
 	int cs_pid;		/* session ID */
 	int dont_term;		/* for special activities like artv so we don't get killed */
+	double created;      /* time of birth */
 	time_t lastcmd;		/* time of last command executed */
 	time_t lastidle;	/* For computing idle time */
-	int state;		/* thread state (see CON_ values below) */
+	CCState state;		/* thread state (see CON_ values below) */
 	int kill_me;		/* Set to nonzero to flag for termination */
 
-	const char *Pos;	/* Our read position inside of the ReadBuf */
-	StrBuf *ReadBuf;	/* Our block buffered read buffer */
-	StrBuf *MigrateBuf;	/* Our block buffered read buffer */
-	const char *sPos;	/* Our read position inside of the ReadBuf */
-	StrBuf *sReadBuf;	/* Our block buffered read buffer */
-	StrBuf *sMigrateBuf;	/* Our block buffered read buffer */
+	IOBuffer SendBuf, /* Our write Buffer */
+		RecvBuf, /* Our block buffered read buffer */
+		SBuf; /* Our block buffered read buffer for clients */
+
+	StrBuf *MigrateBuf;        /* Our block buffered read buffer */
+	StrBuf *sMigrateBuf;        /* Our block buffered read buffer */
+
 	int client_socket;
 	int is_local_socket;	/* set to 1 if client is on unix domain sock */
 	/* Redirect this session's output to a memory buffer? */
 	StrBuf *redirect_buffer;		/* the buffer */
+	StrBuf *StatusMessage;
 #ifdef HAVE_OPENSSL
 	SSL *ssl;
 	int redirect_ssl;
@@ -107,6 +130,7 @@ struct CitContext {
 	struct cit_ical *CIT_ICAL;		/* calendaring data */
 	struct ma_info *ma;			/* multipart/alternative data */
 	const char *ServiceName;		/* readable purpose of this session */
+	long tcp_port;
 	void *openid_data;			/* Data stored by the OpenID module */
 	char *ldap_dn;				/* DN of user when using AUTHMODE_LDAP */
 
@@ -120,23 +144,6 @@ struct CitContext {
 
 typedef struct CitContext CitContext;
 
-/*
- * Values for CitContext.state
- * 
- * A session that is doing nothing is in CON_IDLE state.  When activity
- * is detected on the socket, it goes to CON_READY, indicating that it
- * needs to have a worker thread bound to it.  When a thread binds to
- * the session, it goes to CON_EXECUTING and does its thing.  When the
- * transaction is finished, the thread sets it back to CON_IDLE and lets
- * it go.
- */
-enum {
-	CON_IDLE,		/* This context is doing nothing */
-	CON_GREETING,		/* This context needs to output its greeting */
-	CON_STARTING,		/* This context is outputting its greeting */
-	CON_READY,		/* This context needs attention */
-	CON_EXECUTING		/* This context is bound to a thread */
-};
 
 #define CC MyContext()
 
@@ -155,6 +162,8 @@ void InitializeMasterCC(void);
 void dead_session_purge(int force);
 void set_async_waiting(struct CitContext *ccptr);
 
+CitContext *CloneContext(CitContext *CloneMe);
+
 /* forcibly close and flush fd's on shutdown */
 void terminate_all_sessions(void);
 
@@ -186,4 +195,19 @@ static INLINE void become_session(CitContext *which_con) {
 }
 
 
+
+/* typedef void (*CtdlDbgFunction) (const int); */
+
+extern int DebugSession;
+#define CONDBGLOG(LEVEL) if ((LEVEL != LOG_DEBUG) || (DebugSession != 0))
+
+#define CON_syslog(LEVEL, FORMAT, ...)				\
+	CONDBGLOG(LEVEL) syslog(LEVEL,				\
+				"Context: " FORMAT, __VA_ARGS__)
+
+#define CONM_syslog(LEVEL, FORMAT)			\
+	CONDBGLOG(LEVEL) syslog(LEVEL,			\
+				"Context: " FORMAT);
+
+
 #endif /* CONTEXT_H */
