@@ -415,28 +415,29 @@ void ft_search(int *fts_num_msgs, long **fts_msgs, const char *search_string) {
 
 		}
 		free(tokens);
-		qsort(all_msgs, num_all_msgs, sizeof(long), longcmp);
+		if (all_msgs != NULL) {
+			qsort(all_msgs, num_all_msgs, sizeof(long), longcmp);
 
-		/*
-		 * At this point, if a message appears num_tokens times in the
-		 * list, then it contains all of the search tokens.
-		 */
-		if (num_all_msgs >= num_tokens)
-		   for (j=0; j<(num_all_msgs-num_tokens+1); ++j) {
-			if (all_msgs[j] == all_msgs[j+num_tokens-1]) {
-
-				++num_ret_msgs;
-				if (num_ret_msgs > num_ret_alloc) {
-					num_ret_alloc += 64;
-					ret_msgs = realloc(ret_msgs,
-						(num_ret_alloc*sizeof(long)) );
+			/*
+			 * At this point, if a message appears num_tokens times in the
+			 * list, then it contains all of the search tokens.
+			 */
+			if (num_all_msgs >= num_tokens)
+				for (j=0; j<(num_all_msgs-num_tokens+1); ++j) {
+					if (all_msgs[j] == all_msgs[j+num_tokens-1]) {
+						
+						++num_ret_msgs;
+						if (num_ret_msgs > num_ret_alloc) {
+							num_ret_alloc += 64;
+							ret_msgs = realloc(ret_msgs,
+									   (num_ret_alloc*sizeof(long)) );
+						}
+						ret_msgs[num_ret_msgs - 1] = all_msgs[j];
+						
+					}
 				}
-				ret_msgs[num_ret_msgs - 1] = all_msgs[j];
-
-			}
+			free(all_msgs);
 		}
-
-		free(all_msgs);
 	}
 
 	*fts_num_msgs = num_ret_msgs;
@@ -506,7 +507,7 @@ CTDL_MODULE_INIT(fulltext)
 		CtdlRegisterDeleteHook(ft_delete_remove);
 		CtdlRegisterSearchFuncHook(ft_search, "fulltext");
 		CtdlRegisterCleanupHook(noise_word_cleanup);
-		CtdlRegisterSessionHook(do_fulltext_indexing, EVT_TIMER);
+		CtdlRegisterSessionHook(do_fulltext_indexing, EVT_TIMER, PRIO_CLEANUP + 300);
 	}
 	/* return our module name for the log */
 	return "fulltext";
