@@ -2,7 +2,7 @@
  * This module handles shared rooms, inter-Citadel mail, and outbound
  * mailing list processing.
  *
- * Copyright (c) 2000-2011 by the citadel.org team
+ * Copyright (c) 2000-2012 by the citadel.org team
  *
  *  This program is open source software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -92,6 +92,9 @@
 #include "netmail.h"
 #include "ctdl_module.h"
 
+int NetQDebugEnabled = 0;
+struct CitContext networker_spool_CC;
+
 /* comes from lookup3.c from libcitadel... */
 extern uint32_t hashlittle( const void *key, size_t length, uint32_t initval);
 
@@ -147,8 +150,9 @@ int GetNetworkedRoomNumbers(const char *DirName, HashList *DirList)
  * message from being entered into the database multiple times if it happens
  * to arrive multiple times by accident.
  */
-int network_usetable(struct CtdlMessage *msg) {
-
+int network_usetable(struct CtdlMessage *msg)
+{
+	struct CitContext *CCC = CC;
 	char msgid[SIZ];
 	struct cdbdata *cdbut;
 	struct UseTable ut;
@@ -179,7 +183,7 @@ int network_usetable(struct CtdlMessage *msg) {
 	cdbut = cdb_fetch(CDB_USETABLE, msgid, strlen(msgid));
 	if (cdbut != NULL) {
 		cdb_free(cdbut);
-		syslog(LOG_DEBUG, "network_usetable() : we already have %s\n", msgid);
+		QN_syslog(LOG_DEBUG, "network_usetable() : we already have %s\n", msgid);
 		return(1);
 	}
 
@@ -204,7 +208,9 @@ int network_usetable(struct CtdlMessage *msg) {
  * ignoring anything we know about which messages have already undergone
  * network processing.  This can be used to bring a new node into sync.
  */
-int network_sync_to(char *target_node) {
+int network_sync_to(char *target_node, long len)
+{
+	struct CitContext *CCC = CC;
 	SpoolControl sc;
 	int num_spooled = 0;
 	int found_node = 0;
@@ -223,33 +229,41 @@ int network_sync_to(char *target_node) {
 		end_critical_section(S_NETCONFIGS);
 		return(-1);
 	}
-	while (fgets(buf, sizeof buf, fp) != NULL) {
+	while (fgets(buf, sizeof buf, fp) != NULL)
+	{
 		buf[strlen(buf)-1] = 0;
+
 		extract_token(sc_type, buf, 0, '|', sizeof sc_type);
+		if (strcasecmp(sc_type, "ignet_push_share"))
+			continue;
+
 		extract_token(sc_node, buf, 1, '|', sizeof sc_node);
+		if (strcasecmp(sc_node, target_node))
+			continue;
+
 		extract_token(sc_room, buf, 2, '|', sizeof sc_room);
-		if ( (!strcasecmp(sc_type, "ignet_push_share"))
-		   && (!strcasecmp(sc_node, target_node)) ) {
-			found_node = 1;
+		found_node = 1;
 			
-			/* Concise syntax because we don't need a full linked-list */
-			memset(&sc, 0, sizeof(SpoolControl));
-			sc.ignet_push_shares = (maplist *)
-				malloc(sizeof(maplist));
-			sc.ignet_push_shares->next = NULL;
-			safestrncpy(sc.ignet_push_shares->remote_nodename,
-				sc_node,
-				sizeof sc.ignet_push_shares->remote_nodename);
-			safestrncpy(sc.ignet_push_shares->remote_roomname,
-				sc_room,
-				sizeof sc.ignet_push_shares->remote_roomname);
-		}
+		/* Concise syntax because we don't need a full linked-list */
+		memset(&sc, 0, sizeof(SpoolControl));
+		sc.ignet_push_shares = (maplist *)
+			malloc(sizeof(maplist));
+		sc.ignet_push_shares->next = NULL;
+		safestrncpy(sc.ignet_push_shares->remote_nodename,
+			    sc_node,
+			    sizeof sc.ignet_push_shares->remote_nodename);
+		safestrncpy(sc.ignet_push_shares->remote_roomname,
+			    sc_room,
+			    sizeof sc.ignet_push_shares->remote_roomname);
 	}
 	fclose(fp);
 	end_critical_section(S_NETCONFIGS);
 
 	if (!found_node) return(-1);
 
+	sc.working_ignetcfg = load_ignetcfg();
+	sc.the_netmap = read_network_map();
+
 	/* Send ALL messages */
 	num_spooled = CtdlForEachMessage(MSGS_ALL, 0L, NULL, NULL, NULL,
 		network_spool_msg, &sc);
@@ -257,8 +271,11 @@ int network_sync_to(char *target_node) {
 	/* Concise cleanup because we know there's only one node in the sc */
 	free(sc.ignet_push_shares);
 
-	syslog(LOG_NOTICE, "Synchronized %d messages to <%s>\n",
-		num_spooled, target_node);
+	DeleteHash(&sc.working_ignetcfg);
+	DeleteHash(&sc.the_netmap);
+
+	QN_syslog(LOG_NOTICE, "Synchronized %d messages to <%s>\n",
+		  num_spooled, target_node);
 	return(num_spooled);
 }
 
@@ -268,12 +285,13 @@ int network_sync_to(char *target_node) {
  */
 void cmd_nsyn(char *argbuf) {
 	int num_spooled;
+	long len;
 	char target_node[256];
 
 	if (CtdlAccessCheck(ac_aide)) return;
 
-	extract_token(target_node, argbuf, 0, '|', sizeof target_node);
-	num_spooled = network_sync_to(target_node);
+	len = extract_token(target_node, argbuf, 0, '|', sizeof target_node);
+	num_spooled = network_sync_to(target_node, len);
 	if (num_spooled >= 0) {
 		cprintf("%d Spooled %d messages.\n", CIT_OK, num_spooled);
 	}
@@ -378,7 +396,9 @@ void destroy_network_queue_room_locked (void)
 /*
  * Bounce a message back to the sender
  */
-void network_bounce(struct CtdlMessage *msg, char *reason) {
+void network_bounce(struct CtdlMessage *msg, char *reason)
+{
+	struct CitContext *CCC = CC;
 	char *oldpath = NULL;
 	char buf[SIZ];
 	char bouncesource[SIZ];
@@ -388,7 +408,7 @@ void network_bounce(struct CtdlMessage *msg, char *reason) {
 	static int serialnum = 0;
 	size_t size;
 
-	syslog(LOG_DEBUG, "entering network_bounce()\n");
+	QNM_syslog(LOG_DEBUG, "entering network_bounce()\n");
 
 	if (msg == NULL) return;
 
@@ -477,7 +497,7 @@ void network_bounce(struct CtdlMessage *msg, char *reason) {
 	/* Clean up */
 	if (valid != NULL) free_recipients(valid);
 	CtdlFreeMessage(msg);
-	syslog(LOG_DEBUG, "leaving network_bounce()\n");
+	QNM_syslog(LOG_DEBUG, "leaving network_bounce()\n");
 }
 
 
@@ -491,12 +511,14 @@ void network_bounce(struct CtdlMessage *msg, char *reason) {
  * 
  * Run through the rooms doing various types of network stuff.
  */
-void network_do_queue(void) {
+void network_do_queue(void)
+{
+	struct CitContext *CCC = CC;
 	static int doing_queue = 0;
 	static time_t last_run = 0L;
 	int full_processing = 1;
-	char *working_ignetcfg;
-	NetMap *the_netmap = NULL;
+	HashList *working_ignetcfg;
+	HashList *the_netmap = NULL;
 	int netmap_changed = 0;
 	roomlists RL;
 
@@ -507,7 +529,7 @@ void network_do_queue(void) {
 	if ( (time(NULL) - last_run) < config.c_net_freq ) {
 		full_processing = 0;
 		syslog(LOG_DEBUG, "Network full processing in %ld seconds.\n",
-			config.c_net_freq - (time(NULL)- last_run)
+		       config.c_net_freq - (time(NULL)- last_run)
 		);
 	}
 
@@ -522,6 +544,7 @@ void network_do_queue(void) {
 	}
 	doing_queue = 1;
 
+	become_session(&networker_spool_CC);
 	begin_critical_section(S_RPLIST);
 	RL.rplist = rplist;
 	rplist = NULL;
@@ -537,7 +560,7 @@ void network_do_queue(void) {
 			return;
 	}
 	/* Load the IGnet Configuration into memory */
-	working_ignetcfg = load_working_ignetcfg();
+	working_ignetcfg = load_ignetcfg();
 
 	/*
 	 * Load the network map and filter list into memory.
@@ -551,14 +574,14 @@ void network_do_queue(void) {
 	 * Go ahead and run the queue
 	 */
 	if (full_processing && !server_shutting_down) {
-		syslog(LOG_DEBUG, "network: loading outbound queue\n");
+		QNM_syslog(LOG_DEBUG, "network: loading outbound queue");
 		CtdlForEachRoom(network_queue_interesting_rooms, &RL);
 	}
 
 	if ((RL.rplist != NULL) && (!server_shutting_down)) {
 		RoomProcList *ptr, *cmp;
 		ptr = RL.rplist;
-		syslog(LOG_DEBUG, "network: running outbound queue\n");
+		QNM_syslog(LOG_DEBUG, "network: running outbound queue");
 		while (ptr != NULL && !server_shutting_down) {
 			
 			cmp = ptr->next;
@@ -586,20 +609,29 @@ void network_do_queue(void) {
 	/* If there is anything in the inbound queue, process it */
 	if (!server_shutting_down) {
 		network_do_spoolin(working_ignetcfg, 
-				   &the_netmap,
+				   the_netmap,
 				   &netmap_changed);
 	}
 
-	/* Save the network map back to disk */
-	write_network_map(the_netmap, netmap_changed);
-
 	/* Free the filter list in memory */
 	free_netfilter_list();
 
-	network_consolidate_spoolout(working_ignetcfg, the_netmap);
-	free(working_ignetcfg);
+	/* Save the network map back to disk */
+	if (netmap_changed) {
+		StrBuf *MapStr = SerializeNetworkMap(the_netmap);
+		CtdlPutSysConfig(IGNETMAP, SmashStrBuf(&MapStr));
+	}
 
-	syslog(LOG_DEBUG, "network: queue run completed\n");
+	/* combine singe message files into one spool entry per remote node. */
+	network_consolidate_spoolout(working_ignetcfg, the_netmap);
+
+	/* shut down. */
+
+	DeleteHash(&the_netmap);
+
+	DeleteHash(&working_ignetcfg);
+
+	QNM_syslog(LOG_DEBUG, "network: queue run completed");
 
 	if (full_processing) {
 		last_run = time(NULL);
@@ -684,8 +716,19 @@ void network_logout_hook(void)
 	 */
 	if (!IsEmptyStr(CCC->net_node)) {
 		network_talking_to(CCC->net_node, strlen(CCC->net_node), NTT_REMOVE);
+		CCC->net_node[0] = '\0';
 	}
 }
+void network_cleanup_function(void)
+{
+	struct CitContext *CCC = CC;
+
+	if (!IsEmptyStr(CCC->net_node)) {
+		network_talking_to(CCC->net_node, strlen(CCC->net_node), NTT_REMOVE);
+		CCC->net_node[0] = '\0';
+	}
+}
+
 
 /*
  * Module entry point
@@ -694,18 +737,25 @@ void SetNTTDebugEnabled(const int n)
 {
 	NTTDebugEnabled = n;
 }
+void SetNetQDebugEnabled(const int n)
+{
+	NetQDebugEnabled = n;
+}
 
 CTDL_MODULE_INIT(network)
 {
 	if (!threading)
 	{
+		CtdlFillSystemContext(&networker_spool_CC, "CitNetSpool");
 		CtdlRegisterDebugFlagHook(HKEY("networktalkingto"), SetNTTDebugEnabled, &NTTDebugEnabled);
+		CtdlRegisterDebugFlagHook(HKEY("networkqueue"), SetNetQDebugEnabled, &NetQDebugEnabled);
 		CtdlRegisterCleanupHook(cleanup_nttlist);
-                CtdlRegisterSessionHook(network_logout_hook, EVT_LOGOUT);
+		CtdlRegisterSessionHook(network_cleanup_function, EVT_STOP, PRIO_STOP + 30);
+                CtdlRegisterSessionHook(network_logout_hook, EVT_LOGOUT, PRIO_LOGOUT + 10);
 		CtdlRegisterProtoHook(cmd_nsyn, "NSYN", "Synchronize room to node");
 		CtdlRegisterRoomHook(network_room_handler);
 		CtdlRegisterCleanupHook(destroy_network_queue_room_locked);
-		CtdlRegisterSessionHook(network_do_queue, EVT_TIMER);
+		CtdlRegisterSessionHook(network_do_queue, EVT_TIMER, PRIO_QUEUE + 10);
 	}
 	return "network";
 }
