@@ -1,7 +1,7 @@
 /*
  * This is an implementation of OpenID 2.0 relying party support in stateless mode.
  *
- * Copyright (c) 2007-2011 by the citadel.org team
+ * Copyright (c) 2007-2012 by the citadel.org team
  *
  * This program is open source software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -816,7 +816,6 @@ void cmd_oids(char *argbuf) {
 		return;
 	}
 	memset(oiddata, 0, sizeof(ctdl_openid));
-	CCC->openid_data = (void *) oiddata;
 
 	ArgBuf = NewStrBufPlain(argbuf, -1);
 
@@ -1130,7 +1129,7 @@ void cmd_oidf(char *argbuf) {
 CTDL_MODULE_INIT(openid_rp)
 {
 	if (!threading) {
-		curl_global_init(CURL_GLOBAL_ALL);
+// evcurl call this for us. curl_global_init(CURL_GLOBAL_ALL);
 
 		/* Only enable the OpenID command set when native mode authentication is in use. */
 		if (config.c_auth_mode == AUTHMODE_NATIVE) {
@@ -1141,7 +1140,7 @@ CTDL_MODULE_INIT(openid_rp)
 			CtdlRegisterProtoHook(cmd_oidc, "OIDC", "Create new user after validating OpenID");
 			CtdlRegisterProtoHook(cmd_oida, "OIDA", "List all OpenIDs in the database");
 		}
-		CtdlRegisterSessionHook(openid_cleanup_function, EVT_LOGOUT);
+		CtdlRegisterSessionHook(openid_cleanup_function, EVT_LOGOUT, PRIO_LOGOUT + 10);
 		CtdlRegisterUserHook(openid_purge, EVT_PURGEUSER);
 		openid_level_supported = 1;	/* This module supports OpenID 1.0 only */
 	}
