@@ -1,4 +1,3 @@
-/* $Id$ */
 
 
 #ifndef SERVER_H
@@ -47,6 +46,33 @@ struct CtdlMessage {
 #define CTDLEXIT_LIBCITADEL	106	/* Incorrect version of libcitadel */
 #define CTDL_EXIT_UNSUP_AUTH	107	/* Unsupported auth mode configured */
 
+/*
+ * Reasons why a session would be terminated (set CC->kill_me to these values)
+ */
+enum {
+	KILLME_NOT,
+	KILLME_UNKNOWN,
+	KILLME_CLIENT_LOGGED_OUT,
+	KILLME_IDLE,
+	KILLME_CLIENT_DISCONNECTED,
+	KILLME_AUTHFAILED,
+	KILLME_SERVER_SHUTTING_DOWN,
+	KILLME_MAX_SESSIONS_EXCEEDED,
+	KILLME_ADMIN_TERMINATE,
+	KILLME_SELECT_INTERRUPTED,
+	KILLME_SELECT_FAILED,
+	KILLME_WRITE_FAILED,
+	KILLME_SIMULATION_WORKER,
+	KILLME_NOLOGIN,
+	KILLME_NO_CRYPTO,
+	KILLME_READSTRING_FAILED,
+	KILLME_MALLOC_FAILED,
+	KILLME_QUOTA,
+	KILLME_READ_FAILED,
+	KILLME_ILLEGAL_MANAGESIEVE_COMMAND,
+	KILLME_SPAMMER,
+	KILLME_XML_PARSER
+};
 
 
 #define CS_STEALTH	1	/* stealth mode */
@@ -103,7 +129,6 @@ enum {
 	S_NETCONFIGS,
 	S_PUBLIC_CLIENTS,
 	S_FLOORCACHE,
-	S_DEBUGMEMLEAKS,
 	S_ATBF,
 	S_JOURNAL_QUEUE,
 	S_RPLIST,
@@ -111,7 +136,6 @@ enum {
 	S_CHKPWD,
 	S_LOG,
 	S_NETSPOOL,
-	S_THREAD_LIST,
 	S_XMPP_QUEUE,
 	S_SCHEDULE_LIST,
  	S_SINGLE_USER,
