@@ -1,21 +1,15 @@
 /*
  * Client-side functions which perform room operations
  *
- * Copyright (c) 1987-2010 by the citadel.org team
+ * Copyright (c) 1987-2012 by the citadel.org team
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
- * (at your option) any later version.
+ * This program is open source software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include "sysdep.h"
@@ -38,6 +32,7 @@
 #include "rooms.h"
 #include "commands.h"
 #include "messages.h"
+#include "tuiconfig.h"
 #ifndef HAVE_SNPRINTF
 #include "snprintf.h"
 #endif
@@ -1194,7 +1189,7 @@ void do_edit(CtdlIPC *ipc,
 	char cmd[SIZ];
 	int b, cksum, editor_exit;
 
-	if (IsEmptyStr(editor_paths[0])) {
+	if (IsEmptyStr(editor_path)) {
 		scr_printf("Do you wish to re-enter %s? ", desc);
 		if (yesno() == 0)
 			return;
@@ -1210,7 +1205,7 @@ void do_edit(CtdlIPC *ipc,
 		return;
 	}
 
-	if (!IsEmptyStr(editor_paths[0])) {
+	if (!IsEmptyStr(editor_path)) {
 		CtdlIPC_chat_send(ipc, read_cmd);
 		CtdlIPC_chat_recv(ipc, cmd);
 		if (cmd[0] == '1') {
@@ -1224,7 +1219,7 @@ void do_edit(CtdlIPC *ipc,
 
 	cksum = file_checksum(temp);
 
-	if (!IsEmptyStr(editor_paths[0])) {
+	if (!IsEmptyStr(editor_path)) {
 		char tmp[SIZ];
 
 		snprintf(tmp, sizeof tmp, "WINDOW_TITLE=%s", desc);
@@ -1233,7 +1228,7 @@ void do_edit(CtdlIPC *ipc,
 		editor_pid = fork();
 		if (editor_pid == 0) {
 			chmod(temp, 0600);
-			execlp(editor_paths[0], editor_paths[0], temp, NULL);
+			execlp(editor_path, editor_path, temp, NULL);
 			exit(1);
 		}
 		if (editor_pid > 0)
@@ -1242,7 +1237,7 @@ void do_edit(CtdlIPC *ipc,
 				b = ka_wait(&editor_exit);
 			} while ((b != editor_pid) && (b >= 0));
 		editor_pid = (-1);
-		scr_printf("Executed %s\n", editor_paths[0]);
+		scr_printf("Executed %s\n", editor_path);
 		stty_ctdl(0);
 	} else {
 		scr_printf("Entering %s.  Press return twice when finished.\n", desc);
