@@ -1,5 +1,15 @@
 /*
  * Client-side support functions.
+ *
+ * Copyright (c) 1987-2012 by the citadel.org team
+ *
+ *  This program is open source software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License version 3.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
  */
 
 #include "sysdep.h"
@@ -53,6 +63,7 @@ struct utmp *getutline(struct utmp *ut);
 #include "commands.h"
 #include "citadel_decls.h"
 #include "routines2.h"
+#include "tuiconfig.h"
 
 #define IFAIDE if(axlevel>=AxAideU)
 #define IFNAIDE if (axlevel<AxAideU)
@@ -310,7 +321,7 @@ void enter_config(CtdlIPC *ipc, int mode)
 			0
 		);
 
-		if (!IsEmptyStr(editor_paths[0])) {
+		if (!IsEmptyStr(editor_path)) {
 			user->flags = set_attr(
 				ipc,
 				user->flags,
