@@ -1,6 +1,15 @@
 /*
  * Configuration screens that are part of the text mode client.
  *
+ * Copyright (c) 1987-2012 by the citadel.org team
+ *
+ * This program is open source software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
  */
 
 #include <stdlib.h>
@@ -54,6 +63,7 @@ extern long highest_msg_read;
 extern long maxmsgnum;
 extern unsigned room_flags;
 extern int screenwidth;
+char editor_path[PATH_MAX];
 
 
 /* 
@@ -62,7 +72,7 @@ extern int screenwidth;
 void do_system_configuration(CtdlIPC *ipc)
 {
 
-#define NUM_CONFIGS 68
+	/* NUM_CONFIGS is now defined in citadel.h */
 
 	char buf[256];
 	char sc[NUM_CONFIGS][256];
@@ -355,8 +365,9 @@ void do_system_configuration(CtdlIPC *ipc)
 	scr_printf("Save this configuration? ");
 	if (yesno()) {
 		r = 1;
-		for (a = 0; a < NUM_CONFIGS; a++)
+		for (a = 0; a < NUM_CONFIGS; a++) {
 			r += 1 + strlen(sc[a]);
+		}
 		resp = (char *)calloc(1, r);
 		if (!resp) {
 			scr_printf("Can't save config - out of memory!\n");
@@ -557,7 +568,7 @@ void network_config_management(CtdlIPC *ipc, char *entrytype, char *comment)
 	char *listing = NULL;
 	int r;
 
-	if (IsEmptyStr(editor_paths[0])) {
+	if (IsEmptyStr(editor_path)) {
 		scr_printf("You must have an external editor configured in"
 			" order to use this function.\n");
 		return;
@@ -609,7 +620,7 @@ void network_config_management(CtdlIPC *ipc, char *entrytype, char *comment)
 	if (editor_pid == 0) {
 		chmod(filename, 0600);
 		putenv("WINDOW_TITLE=Network configuration");
-		execlp(editor_paths[0], editor_paths[0], filename, NULL);
+		execlp(editor_path, editor_path, filename, NULL);
 		exit(1);
 	}
 	if (editor_pid > 0) {
